pub struct HttpResponse {
pub status: StatusCode,
pub payload: HttpResponsePayload,
pub headers: Vec<(String, String)>,
}Expand description
A HTTP response Original http response from actix_web can not be shared between threads and cant be used inside async blocks This struct is a wrapper around actix_web::HttpResponse that can be shared between threads.
Fields
status: StatusCodepayload: HttpResponsePayloadheaders: Vec<(String, String)>Implementations
Sourceimpl HttpResponse
impl HttpResponse
pub fn BadRequest() -> HttpResponseBuilder
Sourceimpl HttpResponse
impl HttpResponse
pub fn Ok() -> HttpResponseBuilder
Sourceimpl HttpResponse
impl HttpResponse
pub fn Created() -> HttpResponseBuilder
Sourceimpl HttpResponse
impl HttpResponse
pub fn NotFound() -> HttpResponseBuilder